@@ -184,13 +184,19 @@
 #' freedom used for the \code{mswd} calculation. }
 #'
 #' \item{age}{a 4-element vector with:\cr
+#' 
 #' \code{t}: the concordia age (in Ma)\cr
+#' 
 #' \code{s[t]}: the estimated uncertainty of \code{t}\cr
-#' \code{ci[t]}: the studentised \eqn{100(1-\alpha)\%} confidence
-#' interval of \code{t} for the appropriate degrees of freedom\cr
+#' 
+#' \code{ci[t]}: the \eqn{100(1-\alpha)\%} confidence interval of
+#' 
+#' \code{t} for the appropriate degrees of freedom\cr
+#' 
 #' \code{disp[t]}: the studentised \eqn{100(1-\alpha)\%} confidence
 #' interval for \code{t} augmented by \eqn{\sqrt{mswd}} to account for
-#' overdispersed datasets.}
+#' overdispersed datasets.
+#' }
 #'
 #' }
 #'
@@ -216,8 +222,8 @@
 #'
 #' \code{s}: the estimated standard deviation for \code{x}
 #'
-#' \code{ci}: the studentised \eqn{100(1-\alpha)\%} confidence
-#' interval of \code{x} for the appropriate degrees of freedom
+#' \code{ci}: the \eqn{100(1-\alpha)\%} confidence interval of
+#' \code{x} for the appropriate degrees of freedom
 #'
 #' \code{disp[t]}: the studentised \eqn{100(1-\alpha)\%} confidence
 #' interval for \code{x} augmented by \eqn{\sqrt{mswd}} to account for
@@ -234,9 +240,6 @@
 #' w.r.t the analytical uncertainties (not reported if
 #' \code{show.age=3}).}
 #'
-#' \item{fact}{ the \eqn{(1-\alpha/2)}-percentile of a t-distribution
-#' with \code{df} degrees of freedom. }
-#'
 #' \item{n}{ the number of aliquots in the dataset }
 #'
 #' }
@@ -261,9 +264,9 @@ concordia <- function(x=NULL,tlim=NULL,alpha=0.05,type=1,
                       ellipse.fill=c("#00FF0080","#FF000080"),
                       ellipse.stroke='black',
                       concordia.col='darksalmon',exterr=FALSE,
-                      show.age=0,sigdig=2,common.Pb=0,ticks=5,
-                      anchor=0,hide=NULL,omit=NULL, omit.fill=NA,
-                      omit.stroke='grey',...){    
+                      show.age=0,sigdig=2,common.Pb=0,
+                      ticks=5,anchor=0,hide=NULL,omit=NULL,
+                      omit.fill=NA,omit.stroke='grey',...){    
     if (is.null(x)){
         emptyconcordia(tlim=tlim,alpha=alpha,type=type,exterr=exterr,
                        concordia.col=concordia.col,ticks=ticks,...)
@@ -287,7 +290,7 @@ concordia <- function(x=NULL,tlim=NULL,alpha=0.05,type=1,
         if (measured.disequilibrium(x2calc$d))
             x2calc$d <- replace.impossible.diseq(tt=fit$par[1],d=x2calc$d)
         fit$n <- length(x2calc)
-        discordia.line(fit,wetherill=wetherill,d=x2calc$d)
+        discordia.line(fit,wetherill=wetherill,d=mediand(x2calc$d))
         graphics::title(discordia.title(fit,wetherill=wethertit,sigdig=sigdig))
     }
     plot.concordia.line(x2calc,lims=lims,type=type,col=concordia.col,
@@ -329,7 +332,8 @@ plot.concordia.line <- function(x,lims,type=1,col='darksalmon',
     conc <- matrix(0,nn,2)
     colnames(conc) <- c('x','y')
     for (i in 1:nn){ # build the concordia line
-        xy <- age_to_concordia_ratios(tt[i],type=type,exterr=exterr,d=x$d)
+        xy <- age_to_concordia_ratios(tt[i],type=type,
+                                      exterr=exterr,d=mediand(x$d))
         if (exterr){ # show decay constant uncertainty
             if (i > 1) oldell <- ell
             ell <- ellipse(xy$x[1],xy$x[2],xy$cov,alpha=alpha)
@@ -346,7 +350,8 @@ plot.concordia.line <- function(x,lims,type=1,col='darksalmon',
     if (exterr & ((type==1 & dx<0.03) | (type==2 & dx<3) | (type==3 & dx<0.005)))
     { pos <- NULL } else { pos <- 2 }
     for (i in 1:length(ticks)){
-        xy <- age_to_concordia_ratios(ticks[i],type=type,exterr=exterr,d=x$d)
+        xy <- age_to_concordia_ratios(ticks[i],type=type,
+                                      exterr=exterr,d=mediand(x$d))
         if (exterr){ # show ticks as ellipse
             ell <- ellipse(xy$x[1],xy$x[2],xy$cov,alpha=alpha)
             graphics::polygon(ell,col='white')
@@ -434,11 +439,12 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
         miny <- ylim[1]
         maxy <- ylim[2]
     }
+    md <- mediand(x$d)
     nse <- 3 # number of standard errors used for buffer
     if (is.null(tlim)) out$t <- c(0,0)
     else out$t <- tlim
     if (measured.disequilibrium(x$d)){
-        if (is.null(tlim)) out$t[2] <- meas.diseq.maxt(x$d)
+        if (is.null(tlim)) out$t[2] <- meas.diseq.maxt(md)
         if (type==1){
             if (!xset){
                 Pb7U5 <- get.Pb207U235.ratios(x)
@@ -453,7 +459,7 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
                 maxy <- max(Pb6U8[,1]+nse*Pb6U8[,2],na.rm=TRUE)
             }
             if (is.null(tlim) & maxy<Pb6U8t[2])
-                out$t[2] <- get.Pb206U238.age(maxy,d=x$d)[1]
+                out$t[2] <- get.Pb206U238.age(maxy,d=md)[1]
             out$x <- c(minx,maxx)
             out$y <- c(miny,maxy)
         } else if (type==2){
@@ -465,7 +471,7 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
                 maxx <- max(U8Pb6[,1]+nse*U8Pb6[,2],U8Pb6t,na.rm=TRUE)
             }
             if (is.null(tlim) & maxx>U8Pb6t[1])
-                out$t[1] <- get.Pb206U238.age(1/maxx,d=x$d)[1]
+                out$t[1] <- get.Pb206U238.age(1/maxx,d=md)[1]
             Pb76 <- get.Pb207Pb206.ratios(x)
             if (!yset){
                 Pb76t <- age_to_Pb207Pb206_ratio(out$t,d=x$d)[,'76']
@@ -482,7 +488,7 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
                 maxx <- max(Pb6U8[,1]+nse*Pb6U8[,2],na.rm=TRUE)
             }
             if (is.null(tlim) & maxx>Pb6U8t[1])
-                out$t[2] <- get.Pb206U238.age(1/maxx,d=x$d)[1]
+                out$t[2] <- get.Pb206U238.age(1/maxx,d=md)[1]
             if (!yset){
                 Pb8Th2 <- get.Pb208Th232.ratios(x)
                 Pb8Th2t <- age_to_Pb208Th232_ratio(out$t)[,'82']
@@ -501,7 +507,7 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
                 U238Pb206 <- get.U238Pb206.ratios(x)
                 if (xset) maxx <- out$x[2]
                 else maxx <- max(U238Pb206[,1]+nse*U238Pb206[,2],na.rm=TRUE)
-                out$t[1] <- get.Pb206U238.age(1/maxx,d=x$d)[1]
+                out$t[1] <- get.Pb206U238.age(1/maxx,d=md)[1]
             }
             if (!xset) out$x <- age_to_U238Pb206_ratio(out$t,d=x$d)[,'86']
             if (!yset) out$y <- age_to_Pb207Pb206_ratio(out$t,d=x$d)[,'76']
@@ -519,8 +525,8 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
                 miny <- min(Pb206U238[,1]-nse*Pb206U238[,2],na.rm=TRUE)
                 maxy <- max(Pb206U238[,1]+nse*Pb206U238[,2],na.rm=TRUE)
             }
-            out$t[1] <- get.Pb206U238.age(miny,d=x$d)[1]
-            out$t[2] <- get.Pb207U235.age(maxx,d=x$d)[1]
+            out$t[1] <- get.Pb206U238.age(miny,d=md)[1]
+            out$t[2] <- get.Pb207U235.age(maxx,d=md)[1]
             if (!xset){
                 minx <- min(minx,age_to_Pb207U235_ratio(out$t[1],d=x$d)[,'75'])
                 maxx <- max(maxx,age_to_Pb207U235_ratio(out$t[2],d=x$d)[,'75'])
@@ -542,10 +548,13 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
                 miny <- min(Pb207Pb206[,1]-nse*Pb207Pb206[,2],na.rm=TRUE)
                 maxy <- max(Pb207Pb206[,1]+nse*Pb207Pb206[,2],na.rm=TRUE)
             }
-            out$t[1] <- get.Pb206U238.age(1/maxx,d=x$d)[1]
-            out$t[2] <- get.Pb207Pb206.age(maxy,d=x$d,interval=c(out$t[1],10000))[1]
-            if (!xset) minx <- min(minx,age_to_U238Pb206_ratio(out$t[2],d=x$d)[,'86'])
-            if (!yset) miny <- min(miny,age_to_Pb207Pb206_ratio(out$t[1],d=x$d)[,'76'])
+            out$t[1] <- get.Pb206U238.age(1/maxx,d=mediand(md))[1]
+            out$t[2] <- get.Pb207Pb206.age(maxy,d=mediand(md),
+                                           interval=c(out$t[1],10000))[1]
+            if (!xset)
+                minx <- min(minx,age_to_U238Pb206_ratio(out$t[2],d=md)[,'86'])
+            if (!yset)
+                miny <- min(miny,age_to_Pb207Pb206_ratio(out$t[1],d=md)[,'76'])
             out$x <- c(minx,maxx)
             out$y <- c(miny,maxy)
         } else if (is.null(tlim) & type==3){
@@ -559,11 +568,11 @@ get.concordia.limits <- function(x,tlim=NULL,type=1,xlim,ylim,...){
                 miny <- min(Pb208Th232[,1]-nse*Pb208Th232[,2],na.rm=TRUE)
                 maxy <- max(Pb208Th232[,1]+nse*Pb208Th232[,2],na.rm=TRUE)
             }
-            out$t[1] <- get.Pb206U238.age(minx,d=x$d)[1]
+            out$t[1] <- get.Pb206U238.age(minx,d=md)[1]
             out$t[2] <- get.Pb208Th232.age(maxy)[1]
             if (!xset){
-                minx <- min(minx,age_to_Pb206U238_ratio(out$t[1],d=x$d)[,'68'])
-                maxx <- max(maxx,age_to_Pb206U238_ratio(out$t[2],d=x$d)[,'68'])
+                minx <- min(minx,age_to_Pb206U238_ratio(out$t[1],d=md)[,'68'])
+                maxx <- max(maxx,age_to_Pb206U238_ratio(out$t[2],d=md)[,'68'])
             }
             if (!yset){
                 miny <- min(miny,age_to_Pb208Th232_ratio(out$t[1])[,'82'])
@@ -613,17 +622,20 @@ concordia.age <- function(x,i=NA,type=1,exterr=TRUE,alpha=0.05,...){
         cc4age <- cc
         type4age <- 1
     }
-    tt <- concordia_age_helper(cc4age,d=x$d,type=type4age,exterr=exterr)
+    tt <- concordia_age_helper(cc4age,d=mediand(x$d),type=type4age,exterr=exterr)
     out <- list()
     if (is.na(i)){ # these calculations are only relevant to weighted means
         out <- c(out,mswd.concordia(x,cc4age,type=type4age,tt=tt[1],exterr=exterr))
         out$age <- rep(NA,4)
         names(out$age) <- c('t','s[t]','ci[t]','disp[t]')
-        tfact <- stats::qt(1-alpha/2,out$df['combined'])
         out$age[c('t','s[t]')] <- tt
-        out$age['ci[t]'] <- tfact*out$age['s[t]']
-        if (out$mswd['combined']>1)
-            out$age['disp[t]'] <- tfact*out$mswd['combined']*out$age['s[t]']
+        out$age['ci[t]'] <- ntfact(alpha)*out$age['s[t]']
+        mswd <- list(mswd=out$mswd['combined'],model=1,
+                     p.value=out$p.value['combined'],
+                     df=out$df['combined'],alpha=alpha)
+        if (inflate(mswd)){
+            out$age['disp[t]'] <- ntfact(alpha,mswd)*out$age['s[t]']
+        }
         out$x <- cc$x
         out$cov <- cc$cov
     } else {
@@ -700,7 +712,8 @@ mswd.concordia <- function(x,cc,type=1,tt=0,exterr=TRUE){
     SS.equivalence <- 
         LL.concordia.comp(mu=cc$x,x=x,type=type,mswd=TRUE)
     SS.concordance <- 
-        LL.concordia.age(tt=tt,cc=cc,type=type,exterr=exterr,d=x$d,mswd=TRUE)
+        LL.concordia.age(tt=tt,cc=cc,type=type,exterr=exterr,
+                         d=mediand(x$d),mswd=TRUE)
     df.equivalence <- 2*length(x)-2
     df.concordance <- 1
     mswd <- rep(0,3)
